// Updates: 2006.01.13


/**
 * The listener interface for receiving FileIO events.
 *  
 * @author Michel Deriaz
 */
public interface FileIOListener {


  /**
   * Called when the operation launched by the <code>FileIO.read</code> method 
   * ends up.
   * @param state describes how the operation ended up. Can be
   * <code>STATE_OK</code>, <code>STATE_PROBLEM</code>, 
   * <code>STATE_NOT_READY</code>, or <code>STATE_FILENAME_NULL</code>
   * @param content the content of the file
   */
  public void fileRead(int state, byte[] content);
    

  /**
   * Called when the operation launched by the <code>FileIO.write</code> method 
   * ends up.
   * @param state describes how the operation ended up. Can be
   * <code>STATE_OK</code>, <code>STATE_PROBLEM</code>, 
   * <code>STATE_NOT_READY</code>, <code>STATE_FILENAME_NULL</code>, or
   * <code>STATE_CONTENT_NULL</code>
   */
  public void fileWritten(int state);
  

  /**
   * Called when the operation launched by the <code>FileIO.append</code> method 
   * ends up.
   * @param state describes how the operation ended up. Can be
   * <code>STATE_OK</code>, <code>STATE_PROBLEM</code>, 
   * <code>STATE_NOT_READY</code>, <code>STATE_FILENAME_NULL</code>, or
   * <code>STATE_CONTENT_NULL</code>
   */
  public void fileAppended(int state);
}